@@ -1,6 +1,5 @@
 from ..exceptions import AuthingException
 
-
 def DEFAULT_ONERROR(code, message):
     raise AuthingException(code=code, errmsg=message)
 
@@ -25,6 +24,7 @@ class ManagementClientOptions:
         on_error=None,
         timeout=10.0,
         lang=None,
+        use_unverified_ssl=False
     ):
         # type:(str,str,str,str,any,float) -> ManagementClientOptions
         self.user_pool_id = user_pool_id
@@ -35,3 +35,5 @@ class ManagementClientOptions:
         self.graphql_endpoint = "%s/graphql/v2" % self.host
         self.enc_public_key = enc_public_key or DEFAULT_ENCRYPT_PUBLICKEY
         self.lang = lang
+        self.use_unverified_ssl = use_unverified_ssl
+
